@@ -7,6 +7,8 @@ from bitmovin_api_sdk.common.poscheck import poscheck_model
 
 class CodecConfigType(Enum):
     AAC = "AAC"
+    DTS = "DTS"
+    DTSX = "DTSX"
     DTS_PASSTHROUGH = "DTS_PASSTHROUGH"
     HE_AAC_V1 = "HE_AAC_V1"
     HE_AAC_V2 = "HE_AAC_V2"
